@@ -2,7 +2,7 @@ import os
 import subprocess
 import shutil
 import pty
-import StringIO
+io = __import__("io")
 import threading
 
 from spur.tempdir import create_temporary_dir
@@ -61,7 +61,7 @@ class LocalShell(object):
                 # garbage collection
                 process_stdin = os.fdopen(os.dup(master), "w")
                 process_stdout = os.fdopen(master)
-                process_stderr = StringIO.StringIO()
+                process_stderr = io.BytesIO()
                 
                 def close_slave_on_exit():
                     process.wait()
@@ -132,6 +132,8 @@ class LocalProcess(object):
         
     def stdin_write(self, value):
         self._process_stdin.write(value)
+        # TODO: find a more elegant way of handling buffering that seems to be introduced in Python 3
+        self._process_stdin.flush()
         
     def send_signal(self, signal):
         self._subprocess.send_signal(signal)
