@@ -87,9 +87,9 @@ class SshShell(object):
         process_stdout = channel.makefile('rb')
         
         if store_pid:
-            pid = int(process_stdout.readline().strip())
+            pid = _read_int_line(process_stdout)
             
-        which_return_code = int(process_stdout.readline().strip())
+        which_return_code = _read_int_line(process_stdout)
         
         if which_return_code != 0:
             raise NoSuchCommandError(command[0])
@@ -131,7 +131,7 @@ class SshShell(object):
             for key, value in update_env.iteritems()
         ]
         commands += update_env_commands
-        commands.append("which {0} > /dev/null 2>&1 ; echo $?".format(escape_sh(command_args[0])))
+        commands.append("command -v {0} > /dev/null 2>&1 ; echo $?".format(escape_sh(command_args[0])))
         
         command = " ".join(map(escape_sh, command_args))
         command = "exec {0}".format(command)
@@ -216,6 +216,13 @@ class SshShell(object):
         return connection_error
 
 
+def _read_int_line(output_file):
+    while True:
+        line = output_file.readline().strip()
+        if line:
+            return int(line)
+
+
 class SftpFile(object):
     def __init__(self, sftp, file):
         self._sftp = sftp
